<?php

/**
 * Diese Datei enthält ein Beispiel-Skript zur Übergabe einer neuen Inkasso-Forderung an mediafinanz mit PHP.
 * Das Skript hat lediglich exemplarischen Charakter und dient keinesfalls als vollständige Funktions-Referenz!
 * Die SOAP-Funktionalität steht nur dann zur Verfügung, wenn PHP mit der Option --enable-soap konfiguriert wurde.
 */
 

//Lizenz-Schlüssel der Applikation:
$applicationLicence = 'xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx';

//Lizenz-Schlüssel des Mandanten:
$clientLicence = 'yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy';

//Mandanten-ID:
$clientId = 12345;

//Aus Applikations-Lizenz und Mandanten-Lizenz den Lizenzschlüssel für die Autorisierung bilden:
$licenceKey = md5($applicationLicence . $clientLicence);

//Array für die Authentifizierung bauen:
$auth = array(
    'clientId'   => $clientId,
    'licenceKey' => $licenceKey,
    'sandbox'    => true); //TRUE = Testbetrieb, FALSE = Produktivbetrieb


//Optionen für das SoapClient-Objekt:
$options = array(
    'trace'       => 1,     //so können später u.a. die Methoden __getLastRequest() und __getLastResponse() aufgerufen werden
    'compression' => true,  //Daten werden komprimiert zum Server übertragen
    'exceptions'  => true); //SOAP-Faults werden als Exception weitergereicht


//Nach der Erstellung eines SoapClient-Objekts mittels WSDL-Dokument, stehen die vom Web-Service
//angebotenen Funktionen direkt als Methoden des Objektes zur Verfügung:
$soapClient = new SoapClient('https://soap.mediafinanz.de/encashment210.wsdl', $options);

//Array mit Schuldner-Daten bauen:
$debtor = array(
    'id'          => 1234,            //Kunden-Nummer
    'address'     => 'm',             //Anrede (m = Herr, f = Frau, c = Firma, @ = unbekannt)
    'firstname'   => 'Max',           //Vorname
    'lastname'    => 'Mustermann',    //Nachname
    'company'     => 'Musterfirma',   //Firma
    'co'          => 'bei Schmitt',   //c/o
    'street'      => 'Musterstr. 1a', //Straße und Hausnummer
    'postcode'    => '12345',         //PLZ
    'city'        => 'Berlin',        //Ort
    'country'     => 'DE',            //Länder-Kennzeichen (z.B. DE, AT, CH)
    'telephone1'  => '030-1234567',   //Haupt-Telefonnummer
    'telephone2'  => '030-123876-54', //Weitere Telefonnummer
    'email'       => 'max@muster.de', //Email
    'dateOfBirth' => '1980-12-30');   //Geburtsdatum

//Array mit Forderungsdaten bauen:
$claim = array(
    'invoice'            => '9876',                         //Rechnungs-Nummer
    'type'               => '3',                            //1 = Ware verkauft, 2 = Ware per Vorkasse vekauft, 3 = Dienstleistung erbracht
    'reason'             => 'Beraterhonorar',               //Forderungs-Grund
    'originalValue'      => '120.34',                       //original Rechnungsbetrag (ohne Mahnkosten)
    'overdueFees'        => '5.67',                         //Mahnkosten
    'dateOfOrigin'       => '2014-10-01',                   //Forderungs-Leistungsdatum
    'dateOfLastReminder' => '2014-10-30',                   //Forderungs-Mahndatum (letztes)
    'note'               => 'dies ist eine Test-Forderung', //Bemerkung
    'contractDate'       => '2014-09-01',                   //Forderungs-Vertragsdatum
    'originalCreator'    => 'Testfirma (www.testfirma.de)', //Ursprünglicher Gläubiger
    'catalogReason'      => '40102',                        //Hauptforderungskatalog -> 40102: Beratung
    'catalogText'        => 'Online Beratung'               //Hauptforderungskataloggrund Freitext
);


try
{
    //Web-Service - Funktion zur Übergabe einer neuen Forderung aufrufen:
    $result = $soapClient->newClaim($auth, $claim, $debtor);

    //Rückgabewert auswerten:
    if (!empty($result->fileNumber))
    {
        echo 'Die Forderung wurde erfolgreich unter dem Aktenzeichen ' . $result->fileNumber . ' gespeichert!<br />\n';
    }
    else
    {
        echo "Die Forderung konnte nicht gespeichert werden!<br />\n";

        //alle Fehler ausgeben:
        foreach ($result->errorList as $errorMsg)
        {
        	echo "Fehler: " . $errorMsg . "<br />\n";
        }
    }
}
catch (Exception $e)
{
    echo "Es ist folgender Fehler aufgetreten: " . $e->getMessage() . "<br />\n";
}